# coding=utf-8

from Screens.Screen import Screen
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.Sources.List import List
from Components.Pixmap import Pixmap
from Components.ScrollLabel import ScrollLabel
from Components.Sources.Boolean import Boolean
from enigma import gPixmapPtr
from plugin import plugindir
from os import remove as os_remove
from time import strftime, localtime, time as nowtime, gmtime
from Downloader2 import MygetPage, MydownloadPage, http_failed, headers_gzip, _headers_svg, headers, MyDeferredSemaphore, MyCallLater, _headers_json
from Tools.LoadPixmap import LoadPixmap
from Tools.Directories import pathExists
from weathercheck import weathercheck, DEFAULTSTATIONS, checklist, checklistval
import re
import json
from urllib import quote
from datetime import datetime, timedelta


_masterdict = {}
def make_default_value():
	_masterdict['mlist'] = []
	_masterdict['stations'] = []
	_masterdict['sunmoon'] = []
	_masterdict['wettericon'] = {}
	_masterdict['mytime'] = 0
	_masterdict['startkey'] = 'today'
	_masterdict['changed'] = {'stations':False,'config':False}
	_masterdict['station'] = DEFAULTSTATIONS
	_masterdict['aktuelllist'] = []
	_masterdict['iconupdate'] = []
	_masterdict['furtherdetails'] = None

listmainindex = {}
listmainindex['date'] = 0
listmainindex['timeday'] = 1
listmainindex['daytime'] = 2
listmainindex['wettertext'] = 3
listmainindex['wettericon'] = 4
listmainindex['tempmax'] = 5
listmainindex['tempmin'] = 6
listmainindex['tempfelt'] = 7
listmainindex['raintext'] = 8
listmainindex['rainicon'] = 9
listmainindex['rainamounttext'] = 10
listmainindex['rainamounticon'] = 11
listmainindex['windspeed'] = 12
listmainindex['winddirectiontext'] = 13
listmainindex['winddirectionicon'] = 14
listmainindex['dayposition'] = 15
listmainindex['dummy'] = 16
listmainindex['listend'] = 17

listmainval = ['']*listmainindex['listend']
listmainval[listmainindex['wettericon']] = None
listmainval[listmainindex['rainicon']] = None
listmainval[listmainindex['rainamounticon']] = None
listmainval[listmainindex['winddirectionicon']] = None
listmainval[listmainindex['dayposition']] = -1

listsunmoonindex = {}
listsunmoonindex['date'] = 0
listsunmoonindex['sunrisetitle'] = 1
listsunmoonindex['sunrisevalue'] = 2
listsunmoonindex['sunriseicon'] = 3
listsunmoonindex['sunsettitle'] = 4
listsunmoonindex['sunsetvalue'] = 5
listsunmoonindex['sunseticon'] = 6
listsunmoonindex['moontitle'] = 7
listsunmoonindex['moontext'] = 8
listsunmoonindex['moonicon'] = 9
listsunmoonindex['moonrisetitle'] = 10
listsunmoonindex['moonrisevalue'] = 11
listsunmoonindex['moonriseicon'] = 12
listsunmoonindex['moonsettitle'] = 13
listsunmoonindex['moonsetvalue'] = 14
listsunmoonindex['moonseticon'] = 15
listsunmoonindex['zodiacsignstitle'] = 16
listsunmoonindex['zodiacsignsvalue'] = 17
listsunmoonindex['sunshinetitle'] = 18
listsunmoonindex['sunshinevalue'] = 19
listsunmoonindex['sunshineicon'] = 20
listsunmoonindex['listend'] = 21

listsunmoonval = ['']*listsunmoonindex['listend']
listsunmoonval[listsunmoonindex['sunseticon']] = None
listsunmoonval[listsunmoonindex['moonicon']] = None
listsunmoonval[listsunmoonindex['sunshineicon']] = None
listsunmoonval[listsunmoonindex['moonriseicon']] = None
listsunmoonval[listsunmoonindex['moonseticon']] = None

_downloads = MyDeferredSemaphore(tokens=1)

WEATHER_BASE_URL = "https://www.wetter.com/wetter_aktuell/wettervorhersage/{}"
WEATHER_TODAY_URL = "https://www.wetter.com/{}"
WEATHER_TOMORROW_URL = WEATHER_BASE_URL.format("morgen/{}")

WEATHER_IN_2_DAY_URL = WEATHER_BASE_URL.format("in-2-tagen/{}")
WEATHER_IN_3_DAY_URL = WEATHER_BASE_URL.format("in-3-tagen/{}")
WEATHER_IN_4_DAY_URL = WEATHER_BASE_URL.format("in-4-tagen/{}")
WEATHER_IN_5_DAY_URL = WEATHER_BASE_URL.format("in-5-tagen/{}")
WEATHER_IN_6_DAY_URL = WEATHER_BASE_URL.format("in-6-tagen/{}")

WEATHER_WEEKEND_URL = WEATHER_BASE_URL.format("wochenend_vorhersage/{}")
WEATHER_3_DAY_URL = WEATHER_BASE_URL.format("3_tagesvorhersage/{}")
WEATHER_7_DAY_URL = WEATHER_BASE_URL.format("7_tagesvorhersage/{}")
WEATHER_16_DAY_URL = WEATHER_BASE_URL.format("16_tagesvorhersage/{}")
WEATHER_LOCATION_URL = "https://sayt.wettercomassets.com/prod/suggest/search/{}"
WEATHER_ICON_URL = "https://cs3.wettercomassets.com/wcomv5/images/icons/weather/{}"

WEATHER_STATIONS = "/etc/enigma2/weather_stations.json"
WEATHER_CONFIG = "/etc/enigma2/weather_config.json"
WEATHER_CHECK_CONFIG = "/etc/enigma2/weather_check_config.json"

_pixmap_cache = {}

def Load_My_Pixmap(path):
	svgpath = path[:-3]+'svg'
	if path == '':
		return None
	elif path in _pixmap_cache:
		return _pixmap_cache[path]
	elif svgpath and svgpath in _pixmap_cache:
		return _pixmap_cache[svgpath]
	elif pathExists(svgpath):
		ptr = LoadPixmap(svgpath)
		if ptr:
			_pixmap_cache[svgpath] = ptr
			return ptr
	elif pathExists(path):
		ptr = LoadPixmap(path)
		if ptr:
			_pixmap_cache[path] = ptr
			return ptr
	return None


class MYSimpleSummary(Screen):
	def __init__(self, session, parent):
		Screen.__init__(self, session, parent = parent)
		self.skinName = [ parent.skinName + "_summary"]
		self.skinName.append("SimpleSummary")

class MYSimpleSummary2(Screen):
	def __init__(self, session, parent):
		Screen.__init__(self, session, parent = parent)
		self.skinName = [ parent.skinName + "_summary"]
		self.skinName.append("SimpleSummary")
		self["wettericon"] = Pixmap()
		
	def updatePixmap(self, pixmap):
		self["wettericon"].setPixmap(pixmap)
		
class ChoiceListe(Screen):
	ALLOW_SUSPEND = Screen.SUSPEND_STOPS
	IS_DIALOG = True
	def __init__(self, session, list = [ ], title = "", allow_menu = True, listindex = 0):
		self.skinName = "ChoiceListe"
		Screen.__init__(self, session)
		self["actions"] = ActionMap(["OkCancelActions", "MenuActions"],
		{
			"ok": self.ok,
			"cancel": self._close_,
			"menu": self.showMenu
		}, -1)
		
		self.title = title
		self.allow_menu = allow_menu
		self.close_value = None
		self.listindex = listindex
		self['list'] = List(list=list)
		self.onLayoutFinish.append(self.update_Title)
	
	def ok(self):
		curr = self["list"].getCurrent()
		if curr:
			self.close('OK_ENTRY', curr)
	
	def showMenu(self):
		if self.allow_menu:
			curr = self["list"].getCurrent()
			if curr:
				self.session.openWithCallback(self.showMenuBack, ChoiceBox, title = _("Select"),list = [[_("Remove entry"), "removeentry"]])
	
	def showMenuBack(self, answer=None):
		if answer:
			curr = self["list"].getCurrent()
			if curr:
				self["list"].list.remove(curr)
				self["list"].updateList(self["list"].list)
				self.close_value = 'DEL_ENTRY'
	
	def update_Title(self):
		if self.title:
			self.setTitle(self.title)
		if self.listindex:
			self["list"].index = self.listindex
	
	def createSummary(self):
		return MYSimpleSummary
		
	def _close_(self):
		self.close(self.close_value, None)
		
class WetterComMain(Screen):
	CHANGED_AKTUEL = None
	CHANGED_TITLELIST = None
	INFOICON = None
	def __init__(self, session):
		self.skinName = "WetterComMain"
		Screen.__init__(self, session)
		self["actions"] = ActionMap(["ColorActions", "OkCancelActions", "WizardActions", "MenuActions", "ChannelSelectEPGActions", "EPGSelectActions"],
		{
			"red": self.key_red,
			"green": self.key_green,
			"yellow": self.key_yellow,
			"blue": self.key_blue,
			"cancel": self.close,
			"up": self.moveUp,
			"down": self.moveDown,
			"left": self.left,
			"right": self.right,
			"menu": self.showMenu,
			"showEPGList": self.showInfo,
			"nextService": self.nextStation,
			"prevService": self.prevStation
		}, -1)
		
		make_default_value()
		self["key_red"] = StaticText(_("Today"))
		self["key_green"] = StaticText(_("Tomorrow"))
		self["key_yellow"] = StaticText(_("Weekend"))
		self["key_blue"] = StaticText("16 " + _('Days'))
		
		self["stationname"] = StaticText("")
		self["wettertext"] = StaticText("")
		self["wettericon"] = Pixmap()
		self["temperature"] = StaticText("")
		self["updatetime"] = StaticText("")
		self["namelong"] = StaticText("")
		
		self["infoicon"] = Boolean(False)
		WetterComMain.INFOICON = self["infoicon"]
		WetterComMain.CHANGED_AKTUEL = self.changedaktuel
		WetterComMain.CHANGED_TITLELIST = self._onSelectionChanged
		
		self['liste'] = MYList()
		self['titleliste'] = MYList()
		
		self.mytime = int(nowtime())
		self.choicelisteindex = 0
		self.onClose.append(self.__onClose__)
		self.onLayoutFinish.append(self.firststart)
		_masterdict['aktuelllist'] = checklistval[:]
		read_weather_config()
		self._STATION_ = _masterdict['station'][:]
		self.lastsearch = ''
		self.page = _masterdict['startkey']
		self.start_key()
	
	def firststart(self):
		sindex = listsunmoonindex
		tmplist = listsunmoonval[:]
		#tmplist[sindex['sunshinetitle']] = _('No data available')
		tmplist[sindex['sunriseicon']] = Load_My_Pixmap('{0}icons/ic_classic_weather_sunrise.png'.format(plugindir))
		tmplist[sindex['sunseticon']] = Load_My_Pixmap('{0}icons/ic_classic_weather_sunset.png'.format(plugindir))
		tmplist[sindex['sunshineicon']] = Load_My_Pixmap('{0}icons/ic_classic_sun.png'.format(plugindir))
		tmplist[sindex['moonriseicon']] = Load_My_Pixmap('{0}icons/ic_modern_moonrise.png'.format(plugindir))
		tmplist[sindex['moonseticon']] = Load_My_Pixmap('{0}icons/ic_modern_moonset.png'.format(plugindir))
		tmplist[sindex['moonicon']] = Load_My_Pixmap('{0}icons/ic_modern_moon_4_m.png'.format(plugindir))
		self['titleliste'].setList([tmplist])
		self['titleliste'].setSelectionEnabled(False)
		if _masterdict['startkey'] != 'None':
			self['liste'].setList([listmainval[:]])
		self['liste'].onSelectionChanged.append(self._onSelectionChanged)
				
	def start_key(self):
		if self.page == 'today':
			self.key_red()
		elif self.page == 'tomorrow':
			self.key_green()
		elif self.page == 'weekend':
			self.key_yellow()
		elif self.page == '3days':
			self.key_3days()
		elif self.page == '7days':
			self.key_7days()
		elif self.page == '16days':
			self.key_blue()
		elif self.page == 'in2days':
			self.key_in2days()
		elif self.page == 'in3days':
			self.key_in3days()
		elif self.page == 'in4days':
			self.key_in4days()
		elif self.page == 'in5days':
			self.key_in5days()
		elif self.page == 'in6days':
			self.key_in6days()
	
	def _onSelectionChanged(self):
		curr = self["liste"].getCurrent()
		if curr:
			sindex = listsunmoonindex
			if len(_masterdict['sunmoon']) == 1:
				self['titleliste'].setList([_masterdict['sunmoon'][0][:]])
				self['titleliste'].list[0][sindex['date']] = self['liste'].list[self['liste'].index][sindex['date']]
				if _masterdict['aktuelllist'][checklist['namelong']]:
					self['titleliste'].list[0][sindex['sunshinetitle']] = "{0} {1}  {2}".format(_("Weatherdata"), _masterdict['aktuelllist'][checklist['updatetime']], _masterdict['aktuelllist'][checklist['namelong']])
			elif self['liste'].index < len(_masterdict['sunmoon']):
				self['titleliste'].setList([_masterdict['sunmoon'][self['liste'].index][:]])
				self['titleliste'].list[0][sindex['date']] = self['liste'].list[self['liste'].index][sindex['date']]
				sunshinetitle = self['titleliste'].list[0][sindex['sunshinetitle']]
				if sunshinetitle.startswith('Heute'):
					sunshinetitle = "Am {0} {1}".format(self['titleliste'].list[0][sindex['date']], sunshinetitle[5:])
				elif sunshinetitle.startswith('Die Sonne ist heute'):
					sunshinetitle = "Am {0} {1} {2}".format(self['titleliste'].list[0][sindex['date']], _('ist die Sonne'),sunshinetitle[19:])
				elif sunshinetitle.startswith('Die Sonne zeigt sich'):
					sunshinetitle = "Am {0} {1} {2}".format(self['titleliste'].list[0][sindex['date']], _('zeigt sich die Sonne'),sunshinetitle[20:])
				#if self.page == "3days":
				#	sunshinetitle = self['titleliste'].list[0][sindex['sunshinetitle']].replace("Heute", self['titleliste'].list[0][sindex['date']])
				#else:
				#	sunshinetitle = self['titleliste'].list[0][sindex['sunshinetitle']].replace("Heute", "Am %s" % self['titleliste'].list[0][sindex['date']])
				self['titleliste'].list[0][sindex['sunshinetitle']] = sunshinetitle
			else:
				self['titleliste'].list[0][sindex['date']] = self['liste'].list[self['liste'].index][sindex['date']]
				self['titleliste'].list[0][sindex['sunshinetitle']] = _('No data available')
				self['titleliste'].list[0][sindex['sunrisevalue']] = ''
				self['titleliste'].list[0][sindex['sunsetvalue']] = ''
				self['titleliste'].list[0][sindex['moonrisevalue']] = ''
				self['titleliste'].list[0][sindex['moonsetvalue']] = ''
				self['titleliste'].list[0][sindex['sunshinevalue']] = ''
				self['titleliste'].list[0][sindex['zodiacsignsvalue']] = ''
				self['titleliste'].list[0][sindex['moontext']] = ''
				self['titleliste'].list[0][sindex['moonicon']] = None
			
				self['titleliste'].changedList()
			
	def moveUp(self):
		self['liste'].moveSelection('moveUp')
	
	def moveDown(self):
		self['liste'].moveSelection('moveDown')
	
	def left(self):
		self['liste'].moveSelection('pageUp')
		pass
	
	def right(self):
		self['liste'].moveSelection('pageDown')
	
	def changedaktuel(self):
		_masterdict['aktuelllist'][checklist['namelong']] = self._STATION_[0]
		#self.setTitle(_masterdict['aktuelllist'][checklist['title']])
		self["stationname"].text = _masterdict['aktuelllist'][checklist['stationname']]
		self["wettertext"].text = _masterdict['aktuelllist'][checklist['wettertext']]
		if _masterdict['aktuelllist'][checklist['wettericon']]:
			self["wettericon"].setPixmap(_masterdict['aktuelllist'][checklist['wettericon']])
			self.summaries.updatePixmap(_masterdict['aktuelllist'][checklist['wettericon']])
		self["temperature"].text = _masterdict['aktuelllist'][checklist['temperature']]
		self["updatetime"].text = _masterdict['aktuelllist'][checklist['updatetime']]
		self["namelong"].text = _masterdict['aktuelllist'][checklist['namelong']]
		
	def download_page(self, myurl):
		_masterdict['mlist'] = []
		_masterdict['sunmoon'] = []
		self.setTitle(_('Getting weather information...'))
		#self['liste'].setList([listmainval[:]])
		_downloads.settokens(1)
		_downloads.run(MygetPage, url=myurl, headers=headers_gzip).addCallback(self.result_back).addErrback(http_failed, title='Wetter.com download_page')
	
	def result_back(self, result):
		if result:
			val = parse_main(result)
			if val:
				self.setTitle(val.group(1))
				self['liste'].setList(_masterdict['mlist'])
				if _downloads.finished():
					#print _downloads.finished()
					#print len(_masterdict['wettericon'])
					if _masterdict['wettericon']:
						_downloads.settokens(len(_masterdict['wettericon']))
						for iconid in _masterdict['wettericon']:
							urlpix = _masterdict['wettericon'][iconid][0][0]
							file = _masterdict['wettericon'][iconid][0][1]
							_downloads.run(MydownloadPage, url=urlpix, file=file, headers=_headers_svg).addCallback(self.result_back_pix, file, iconid).addErrback(http_failed, title='Wetter.com result_back_pix')
	
	def result_back_pix(self, result, file, iconid):
		if pathExists(file):
			ptr = Load_My_Pixmap(file)
			if _masterdict['wettericon']:
				for val in _masterdict['wettericon'][iconid]:
					self['liste'].list[val[2]][listmainindex['wettericon']] = ptr
					self['liste'].changedList()
				if _downloads.finished():
					_masterdict['wettericon'].clear()
		
	def key_red(self):
		_masterdict['aktuelllist'] = checklistval[:]
		_masterdict['furtherdetails'] = None
		_masterdict['mytime'] = self.mytime
		self.page = "today"
		self.download_page(WEATHER_TODAY_URL.format(self._STATION_[1]))
	
	def key_green(self):
		_masterdict['mytime'] = self.mytime + 86400
		self.page = "tomorrow"
		self.download_page(WEATHER_TOMORROW_URL.format(self._STATION_[1]))
		
	def key_yellow(self):
		self.page = "weekend"
		self.download_page(WEATHER_WEEKEND_URL.format(self._STATION_[1]))
	
	def key_3days(self):
		self.page = "3days"
		self.download_page(WEATHER_3_DAY_URL.format(self._STATION_[1]))
	
	def key_7days(self):
		self.page = "7days"
		self.download_page(WEATHER_7_DAY_URL.format(self._STATION_[1]))
		
	def key_blue(self):
		self.page = "16days"
		self.download_page(WEATHER_16_DAY_URL.format(self._STATION_[1]))
	
	def key_in2days(self):
		_masterdict['mytime'] = self.mytime + (86400 * 2)
		self.page = "in2days"
		self.download_page(WEATHER_IN_2_DAY_URL.format(self._STATION_[1]))
		
	def key_in3days(self):
		_masterdict['mytime'] = self.mytime + (86400 * 3)
		self.page = "in3days"
		self.download_page(WEATHER_IN_3_DAY_URL.format(self._STATION_[1]))
		
	def key_in4days(self):
		_masterdict['mytime'] = self.mytime + (86400 * 4)
		self.page = "in4days"
		self.download_page(WEATHER_IN_4_DAY_URL.format(self._STATION_[1]))
		
	def key_in5days(self):
		_masterdict['mytime'] = self.mytime + (86400 * 5)
		self.page = "in5days"
		self.download_page(WEATHER_IN_5_DAY_URL.format(self._STATION_[1]))
		
	def key_in6days(self):
		_masterdict['mytime'] = self.mytime + (86400 * 6)
		self.page = "in6days"
		self.download_page(WEATHER_IN_6_DAY_URL.format(self._STATION_[1]))
	
	def showInfo(self):
		if _masterdict['furtherdetails']:
			self.session.open(WetterComFurther)
	
	def changeStation(self, diff):
		listindex=-1
		if not _masterdict['stations']:
			read_weather_stations()
		if len(_masterdict['stations']) >1:
			if self._STATION_ in _masterdict['stations']:
				listindex = _masterdict['stations'].index(self._STATION_) + diff
				if listindex <0:
					listindex = len(_masterdict['stations'])-1
				elif listindex > len(_masterdict['stations'])-1:
					listindex = 0
			else:
				listindex = 0
		
		if listindex>=0:
			self._STATION_ = _masterdict['stations'][listindex]
			_masterdict['aktuelllist'] = checklistval[:]
			_masterdict['furtherdetails'] = None
			self["infoicon"].boolean = False
			self.start_key()
			"""if self.page == "today":
				self.key_red()
			elif self.page == "tomorrow":
				self.key_green()
			elif self.page == "weekend":
				self.key_yellow()
			elif self.page == "3days":
				self.key_3days()
			elif self.page == "7days":
				self.key_7days()
			elif self.page == "16days":
				self.key_blue()"""

	def nextStation(self):
		self.changeStation(+1)
	
	def prevStation(self):
		self.changeStation(-1)
		
	def showMenu(self):
		choices = []
		choices.append((_("Weather") + ' ' + "3 " + _('Days') + ' ' + _("overview"), '3days'))
		choices.append((_("Weather") + ' ' + "7 " + _('Days') + ' ' + _("overview"), '7days'))
		
		mytime = int(nowtime())
		choices.append((_("Weather") + ' ' + _('in {0} days').format('2') + ' ' + strftime("%a %d.%m.%y", localtime(mytime + (86400 * 2))), 'in2days'))
		choices.append((_("Weather") + ' ' + _('in {0} days').format('3') + ' ' + strftime("%a %d.%m.%y", localtime(mytime + (86400 * 3))), 'in3days'))
		choices.append((_("Weather") + ' ' + _('in {0} days').format('4') + ' ' + strftime("%a %d.%m.%y", localtime(mytime + (86400 * 4))), 'in4days'))
		choices.append((_("Weather") + ' ' + _('in {0} days').format('5') + ' ' + strftime("%a %d.%m.%y", localtime(mytime + (86400 * 5))), 'in5days'))
		choices.append((_("Weather") + ' ' + _('in {0} days').format('6') + ' ' + strftime("%a %d.%m.%y", localtime(mytime + (86400 * 6))), 'in6days'))
		
		if not _masterdict['stations']:
			read_weather_stations()
		if _masterdict['stations']:
			choices.append((_("Weather") + ' ' + _("Stations"), 'weatherstations'))
		choices.append((_("Weather") + ' ' + _("Stations") + ' ' + _('search'), 'weatherstationsearch'))
		choices.append((_("Weather") + '.com Plugin ' + _('Setup'), 'wettercommainsetup'))
		
		try:
			from Components.Sources.WetterCom import WetterCom
			from Plugins.Extensions.WetterComComponent.plugin import wettercomsetup
			choices.append((_("Weather") + '.com ' +_('Automatic update checks') + ' ' + _('Setup'), 'wettercomsetup'))
		except:
			pass

		self.session.openWithCallback(
			self.showMenuBack,
			ChoiceListe,
			title = _("Select"),
			list = choices,
			allow_menu = False,
			listindex = self.choicelisteindex
		)
		
	def showMenuBack(self, answer = None, value = None):
		if answer and answer == 'OK_ENTRY' and value and value[1]:
			if value[1] == '3days':
				self.choicelisteindex = 0
				self.key_3days()
			elif value[1] == '7days':
				self.choicelisteindex = 1
				self.key_7days()
			elif value[1] == 'in2days':
				self.choicelisteindex = 2
				self.key_in2days()
			elif value[1] == 'in3days':
				self.choicelisteindex = 3
				self.key_in3days()
			elif value[1] == 'in4days':
				self.choicelisteindex = 4
				self.key_in4days()
			elif value[1] == 'in5days':
				self.choicelisteindex = 5
				self.key_in5days()
			elif value[1] == 'in6days':
				self.choicelisteindex = 6
				self.key_in6days()
			elif value[1] == 'weatherstations':
				listindex = 0
				self.choicelisteindex = 7
				#print _masterdict['stations']
				if self._STATION_ in _masterdict['stations']:
					listindex = _masterdict['stations'].index(self._STATION_)
				self.session.openWithCallback(self.download_page_add_favo, ChoiceListe, list = _masterdict['stations'], title = _("Weather") + ' ' + _("Stations") + ' ' + _("Select"), allow_menu = True, listindex = listindex)
			elif value[1] == 'weatherstationsearch':
				self.choicelisteindex = 8
				from Plugins.SystemPlugins.Toolkit.NTIVirtualKeyBoard import NTIVirtualKeyBoard
				self.session.openWithCallback(self.wetterstation_back, NTIVirtualKeyBoard, title = _("Search by location or zip code"), text=self.lastsearch)
			elif value[1] == 'wettercommainsetup':
				self.choicelisteindex = 9
				self.session.open(WetterComMainSetup)
			elif value[1] == 'wettercomsetup':
				self.choicelisteindex = 10
				from Plugins.Extensions.WetterComComponent.plugin import wettercomsetup
				wettercomsetup(self.session, is_dialog=True)
			
			
	def wetterstation_back(self, query = None):
		if query:
			self.lastsearch = query
			_downloads.settokens(1)
			_downloads.run(MygetPage, url=WEATHER_LOCATION_URL.format(quote(query)), headers=_headers_json).addCallback(self.result_station_back).addErrback(http_failed, title='Wetter.com result_station_back')
	
	def result_station_back(self, result = None):
		if result:
			val = parse_json(result)
			self.session.openWithCallback(
				self.download_page_add_favo,
				ChoiceListe,
				title = _("Select"),
				list = val,
				allow_menu = False
			)
	
	def download_page_add_favo(self, answer = None, value = None):
		#print answer
		if answer and answer == 'OK_ENTRY' and value and value[1]:
			if list(value) not in _masterdict['stations']:
				_masterdict['changed']['stations'] = True
				_masterdict['stations'].insert(0, value)
			self._STATION_ = list(value)
			_masterdict['aktuelllist'] = checklistval[:]
			_masterdict['furtherdetails'] = None
			self["infoicon"].boolean = False
			self['liste'].setList([listmainval[:]])
			self.start_key()
		elif answer and answer == 'DEL_ENTRY':
			_masterdict['changed']['stations'] = True
			if self._STATION_ not in _masterdict['stations']:
				if _masterdict['stations']:
					self._STATION_ = _masterdict['stations'][0]
				else:
					self._STATION_ = DEFAULTSTATIONS
		
	def createSummary(self):
		return MYSimpleSummary2
		
	def __onClose__(self):
		if _masterdict['changed']['stations']:
			write_weather_stations()
		if _masterdict['changed']['config']:
			write_weather_config()
		_masterdict.clear()
		_pixmap_cache.clear()
	

class WetterComFurther(Screen):
	IS_DIALOG = True
	ALLOW_SUSPEND = Screen.SUSPEND_STOPS
	def __init__(self, session):
		self.skinName = "WetterComFurther"
		windowTitle = "WetterComFurther"
		value = None
		listval = []
		textval = ""
		if _masterdict['furtherdetails']:
			value = parse_furtherdetails(_masterdict['furtherdetails'])
			windowTitle = value[0][0]
			listval = value[1]
			textval = "{0}\n\n{1}".format(value[0][1], value[0][2])
		Screen.__init__(self, session, windowTitle=windowTitle)
		self["description"] = ScrollLabel(textval)
		self["actions"] = ActionMap(["SetupActions", "InfobarMovieListActions"],
			{
				"cancel": self.close,
				"up": self["description"].pageUp,
				"down": self["description"].pageDown
			})
					
		self['liste'] = MYList(listval)
		
		
	def createSummary(self):
		return MYSimpleSummary
	
class MYList(List):
	def __init__(self, list = [ ], enableWrapAround = False, item_height = 25, fonts = [ ], buildfunc = None):
		List.__init__(self, list = list, enableWrapAround = enableWrapAround, item_height = item_height, fonts = fonts, buildfunc = buildfunc)
		self.__list = list
		
	def extList(self, list):
		self.list.extend(list)
		self.changed((self.CHANGED_ALL,))
	
	def sort(self, key=0):
		self.list.sort(key=key)
		self.changed((self.CHANGED_ALL,))
		
	def clearList(self):
		if self.list:
			del self.list[:]
			self.changed((self.CHANGED_CLEAR,))
	
	def changedList(self):
		self.changed((self.CHANGED_ALL,))
		
	def modifyEntryVal(self, index, data, indexval):
		self.list[index][indexval] = data
		self.entry_changed(index)
		
	def moveUp(self):
		self.moveSelection("moveUp")

	def moveDown(self):
		self.moveSelection("moveDown")
		
	def getList(self):
		return self.list[:]
		
from Components.ConfigList import ConfigListScreen
from Components.config import config, getConfigListEntry, ConfigSelection, ConfigSubsection, NoSave, ConfigDirectory, ConfigYesNo, ConfigNothing

class WetterComSetup(Screen, ConfigListScreen):
	IS_DIALOG = False
	ALLOW_SUSPEND = Screen.SUSPEND_STOPS
	def __init__(self, session):
		Screen.__init__(self, session)
		ConfigListScreen.__init__(self, [], session=session, on_change=self._onChange)
		self.skinName = "Setup"

		self["key_red"] = StaticText(_("Time") + ' ' + _("Reset"))
		self["key_green"] = StaticText(_("Save"))
		self["key_yellow"] = StaticText(_("Refresh"))

		self["actions"] = ActionMap(["ColorActions", "SetupActions"],
			{
				"cancel": self.keyCancel,
				"red": self.key_red,
				"yellow": self.key_yellow,
				"save": self.keySave
			})
			
		self.settings = ConfigSubsection()
		self.settings.station = None
		self.settings.nextcheck = None
		self.settings.counter = None
		self.settings.running = None
		self.settings.runtime = None
		self.settings.infobarscreen = None
		self.settings.stopstandby = None
		self.listindex = 0
		
		if not _masterdict['stations']:
			read_weather_stations()
		
		self.settings.infobarscreen = NoSave(ConfigYesNo(default = weathercheck.get('infobarscreen', False)))
		self.settings.stopstandby = NoSave(ConfigYesNo(default = weathercheck.get('stopstandby', True)))
			
		choices = []
		choices.append(('0', _('Disabled')))
		choices.append(('900', '15 ' + _('mins')))
		choices.append(('1800', '30 ' + _('mins')))
		choices.append(('2700', '45 ' + _('mins')))
		choices.append(('3600', '1 ' + _('hour')))
		choices.append(('3602', _('full hour') + ' + 2 ' + _('mins') + ' (xx:02)'))
		choices.append(('3622', _('full hour') + ' + 22 ' + _('mins') + ' (xx:22)'))
		choices.append(('7200', '2 ' + _('hours')))
		choices.append(('10800', '3 ' + _('hours')))
		choices.append(('14400', '4 ' + _('hours')))
		choices.append(('18000', '5 ' + _('hours')))
		choices.append(('21600', '6 ' + _('hours')))
		self.settings.interval = NoSave(ConfigSelection(default = '{0}'.format(weathercheck.get('interval', '0')), choices = choices))
		
		choices = []
		if weathercheck['station'] not in _masterdict['stations']:
			_masterdict['stations'].append(weathercheck['station'])
		for name, url, id in _masterdict['stations']:
			choices.append((url, name, id))
		
		self.settings.station = NoSave(ConfigSelection(default = weathercheck['station'][1], choices = choices))
		
		self.onLayoutFinish.append(self.firststart)
		self._createSetup()
			
	def _onChange(self):
		self._createSetup()
		
	def firststart(self):
		self.setTitle(_("Weather") + ".com " + _('Automatic update checks') + ' ' + _("Setup"))
		self["config"].setCurrentIndex(self.listindex)
		
	def _createSetup(self):
		running = _('State - Disabled')
		if weathercheck['loopingcall'] and weathercheck['loopingcall'].running:
			running = _('State - Running')
			try:
				mtime = weathercheck['loopingcall']._expectNextCallAt - weathercheck['loopingcall'].clock.seconds()
				if mtime < 3600:
					nextcheck = strftime("%M:%S", gmtime(mtime)) + ' ' + _('minutes')
				else:
					nextcheck = strftime("%H:%M:%S", gmtime(mtime)) + ' ' + _('hours')
				self.settings.nextcheck = NoSave(ConfigSelection(default = '0', choices = [('0', nextcheck)]))
			except:
				pass
			
			#self.settings.nextcheck = NoSave(ConfigSelection(default = '0', choices = [('0', datetime.fromtimestamp(int(nowtime()) + weathercheck['loopingcall'].interval).strftime("%H:%M:%S " + _('clock')))]))
			
			counter = '{}'.format(weathercheck['loopingcall']._intervalOf(weathercheck['loopingcall'].clock.seconds()))
			self.settings.counter = NoSave(ConfigSelection(default = '0', choices = [('0', counter)]))
			
			
			timestr = ""
			secs = int(weathercheck['loopingcall'].clock.seconds() - weathercheck['loopingcall'].starttime)
			days = secs//86400
			if days > 0:
				timestr += "{0} {1} ".format(days, _('Days'))
			hours = (secs - days*86400)//3600
			if hours > 0:
				timestr += "{0} {1} ".format(hours, _('hours'))
			minutes = (secs - days*86400 - hours*3600)//60
			if minutes > 0:
				timestr += "{0} {1} ".format(minutes, _('mins'))
			seconds = secs - days*86400 - hours*3600 - minutes*60
			if seconds > 0:
				timestr += "{0} {1}".format(seconds, _('seconds'))
			if timestr:
				self.settings.runtime = NoSave(ConfigSelection(default = '0', choices = [('0', timestr)]))
		
		self.settings.running = NoSave(ConfigSelection(default = '0', choices = [('0', running)]))
		
		
		entries = []
		
		entries.append(getConfigListEntry(_('State'), self.settings.running))
		self.listindex += 1
		if self.settings.runtime:
			self.listindex += 1
			entries.append(getConfigListEntry(_('Runtime:'), self.settings.runtime))
		
		if self.settings.counter:
			self.listindex += 1
			entries.append(getConfigListEntry(_('Counter'), self.settings.counter))
		if self.settings.nextcheck:
			self.listindex += 1
			entries.append(getConfigListEntry(_('Next check'), self.settings.nextcheck))
		#self.listindex += 1
		#self.listindex += 1
		entries.append(getConfigListEntry('  '))
		
		#entries.append(getConfigListEntry('huhu'))
		
		valuestr = ' global.WetterCom='# disabled
		if int(self.settings.interval.value) > 100: 
			valuestr +=  _('enabled')
		else:
			valuestr +=  _('disabled')
		valuestr +=  '  /  ' + _('InfoBar') + '='
		if self.settings.infobarscreen.value:
			valuestr +=  _('enabled')
		else:
			valuestr +=  _('disabled')
		valuestr +=  '  /  ' + _("Stop") + ' ' + _('Standby') + '='
		if self.settings.stopstandby.value:
			valuestr +=  _('enabled')
		else:
			valuestr +=  _('disabled')
			
		self.listindex += 1
		entries.append(getConfigListEntry(valuestr))
		
		self.listindex += 1
		entries.append(getConfigListEntry(_('disable') + ' / ' + _('Interval'), self.settings.interval))
		
		if int(self.settings.interval.value) > 100:
			entries.append(getConfigListEntry(_('Show Weather Forecast') + ' / ' + _('InfoBar'), self.settings.infobarscreen))
			entries.append(getConfigListEntry(_('Stop Refresh') + ' / ' + _('Standby'), self.settings.stopstandby))
			entries.append(getConfigListEntry((_("Weather") + ' ' + _("Stations") + ' ' + _("Default")), self.settings.station))
		
		self["config"].list = entries
		
	
	def keySave(self):
		if self["config"].isChanged():
			weathercheck['interval'] = int(self.settings.interval.value)
			weathercheck['stopstandby'] = self.settings.stopstandby.value
			weathercheck['infobarscreen'] = self.settings.infobarscreen.value
			res = self.settings.station.getChoices()[self.settings.station.index]
			weathercheck['station'] = [res[1],res[0],res[2]]
			
			write_weather_check_config()
			
			self.close(True)
		else:
			self.close(False)
		
	def key_red(self):
		if weathercheck['loopingcall']:
			weathercheck['loopingcall'].reset()
			self._createSetup()
			loopweathercheck()
	
	def key_yellow(self):
		loopweathercheck()


class WetterComMainSetup(Screen, ConfigListScreen):
	IS_DIALOG = True
	ALLOW_SUSPEND = Screen.SUSPEND_STOPS
	def __init__(self, session):
		Screen.__init__(self, session)
		ConfigListScreen.__init__(self, [], session=session, on_change=None)
		self.skinName = "Setup"
		
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("Save"))

		self["actions"] = ActionMap(["ColorActions", "SetupActions"],
			{
				"cancel": self.keyCancel,
				"red": self.keyCancel,
				"save": self.keySave
			})
		
		self.onLayoutFinish.append(self.layoutFinished)
		self.settings = ConfigSubsection()
		#self.settings.station = _masterdict.get('station', DEFAULTSTATIONS)
		#self.settings.startkey = _masterdict.get('startkey', 'key_red')
		
		choices = []
		if _masterdict['station'] not in _masterdict['stations']:
			_masterdict['stations'].append(_masterdict['station'])
		for name, url, id in _masterdict['stations']:
			choices.append((url, name, id))
		
		self.settings.station = NoSave(ConfigSelection(default = _masterdict['station'][1], choices = choices))
		choices = []
		choices.append(('None', _('Disabled')))
		choices.append(('today', _("Weather") + ' ' + _('Today')))
		choices.append(('tomorrow', _("Weather") + ' ' + _('Tomorrow')))
		choices.append(('weekend', _("Weather") + ' ' + _('Weekend')))
		choices.append(('3days', _("Weather") + ' ' + "3 " + _('Days')))
		choices.append(('7days', _("Weather") + ' ' + "7 " + _('Days')))
		choices.append(('16days', _("Weather") + ' ' + "16 " + _('Days')))
		choices.append(('in2days', _("Weather") + ' ' + _('in {0} days').format('2')))
		choices.append(('in3days', _("Weather") + ' ' + _('in {0} days').format('3')))
		choices.append(('in4days', _("Weather") + ' ' + _('in {0} days').format('4')))
		choices.append(('in5days', _("Weather") + ' ' + _('in {0} days').format('5')))
		choices.append(('in6days', _("Weather") + ' ' + _('in {0} days').format('6')))
		
		self.settings.startkey = NoSave(ConfigSelection(default = _masterdict.get('startkey', 'today'), choices = choices))
		entries = []
		entries.append(getConfigListEntry(_('Start from the beginning'), self.settings.startkey))
		entries.append(getConfigListEntry((_("Weather") + ' ' + _("Stations") + ' ' + _("Default")), self.settings.station))
		
		self["config"].list = entries
	
	def layoutFinished(self):
		self.setTitle(_("Weather") + '.com Plugin ' + _('Setup'))
		
	def keySave(self):
		if self["config"].isChanged():
			_masterdict['startkey'] = self.settings.startkey.value
			res = self.settings.station.getChoices()[self.settings.station.index]
			_masterdict['station'] = [res[1],res[0],res[2]]
			write_weather_config()
			
			self.close(True)
		else:
			self.close(False)
_moondict = {}
_moondict['moon_first_quarter'] = 'ic_modern_moon_2_m'
_moondict['moon_waxing_crescent'] = 'ic_modern_moon_1_m'
_moondict['moon_new_moon'] = 'ic_modern_moon_0_m'
_moondict['moon_waning_crescent'] = 'ic_modern_moon_7_m'
_moondict['moon_waning_gibbous'] = 'ic_modern_moon_5_m'
_moondict['moon_waxing_gibbous'] = 'ic_modern_moon_3_m'
_moondict['moon_last_quarter'] = 'ic_modern_moon_6_m'
_moondict['moon_full_moon'] = 'ic_modern_moon_4_m'
_moondict['moonrise'] = 'ic_modern_moonrise'
_moondict['moonset'] = 'ic_modern_moonset'



#titledescription_com = re.compile(r'<h1 class="mb0">(.+?)</h1>', re.S|re.I)
titledescription_com = re.compile(r'<title>(.+?)</title>', re.S|re.I)
master_com = re.compile(r'<div class="swg-row-wrapper border.+<div class="swg-col-wv3 swg-row">.+?</div>', re.S)
master_val_com = re.compile('<div class="swg-row-wrapper border.+?<div class="swg-col-wv3 swg-row">.+?</div>', re.S)
master2_com = re.compile(r'<div class="spaces-weather-grid.+<div class="swg-col-arrow swg-row span-3">.+?</div>.+?</div>', re.S|re.I)
master2_val_com = re.compile('data-onclick="openGrid".+?<div class="swg-col-arrow swg-row span-3">.+?</div>', re.S)
#master3_com = re.compile(r'<div class="swg-row-wrapper border.+?data-num="1".+?<div class="swg-col-wv3 swg-row">.+?</div>', re.S)
master3_com = re.compile(r'<div class="swg-row-wrapper border--grey-next border--grey-top.+?<div class="swg-col-wv3 swg-row">.+?</div>', re.S)

date_com = re.compile(r'<div class="swg-col-period swg-row" >(.+?)</div>', re.S)
#data_grid_parent_com = re.compile(r'data-grid-parent="(.+?)"', re.S)
data_grid_child_com = re.compile(r'data-grid-child="(.+?)"', re.S)
data_num_com = re.compile(r'data-num="(.+?)"', re.S)
swg_col_period_com = re.compile(r'<div class="swg-col-period swg-row">(.+?)</div>', re.S)
swg_col_text_com = re.compile(r'<div class="swg-col-text swg-row">(.+?)</div>', re.S)

wettericon_com = re.compile(r'data-single-src=.+?icons/weather/(.+?)"', re.S)
wettericonurl_com = re.compile(r'data-single-src="(.+?)"', re.S)
wettericonsvg_com = re.compile(r'https.+?icons/weather/(.+?)"', re.S)
tempmax_com = re.compile(r'<span class="swg-text-large">(.+?)</span>', re.S)
#tempmin_com = re.compile(r'<span class="swg-text-small portable-hide">(.+?)</span>', re.S)
tempmin2_com = re.compile(r'<span class="swg-text-small">(.+?)</span>', re.S)
#wettertext_com = re.compile(r'<div class="swg-col-weather-text swg-row portable-hide">(.+?)</div>', re.S)
raintext_com = re.compile(r'<div class="swg-col-wv1 swg-row">(.+?)</div>', re.S)
rainamount_com = re.compile(r'<div class="swg-col-wv2 swg-row">(.+?)</div>', re.S)
winddirection_com = re.compile(r'.+</span>(.+?)</div>.+?<div class="swg-col-wv3 swg-row">', re.S)
windspeed_com = re.compile(r'<div class="swg-col-wv3 swg-row">(.+?)</div>', re.S)
tempfelt_com = re.compile(r'<span class="portable-hide">(.+?)</span>(.+?)</div>', re.S)

sun_moon_master_com = re.compile('<div class="sun-moon relative">.+?</table>.+?</script>', re.S|re.I)
sun_moon_sunrise_com = re.compile('<span class="text--yellow icon-sunrise.+?title="(.+?)"></span>.+?">(.+?)</span>', re.S|re.I)
sun_moon_sunset_com = re.compile('<span class="text--yellow icon-sunset.+?title="(.+?)"></span>.+?">(.+?)</span>', re.S|re.I)
sun_moon_sunshine_com = re.compile('<span class="text.+?portable-mr-- portable-hide">(.+?)</span>.+?portable-mr--">(.+?)</span>', re.S|re.I)
sun_moon_moonicon_com = re.compile('<span class="icon-(moon.+?).icon--small".title="(.+?)"></span>', re.S|re.I)
sun_moon_moontext_com = re.compile('<span class="vhs-text.+?">(.+?)</span>', re.S|re.I)
sun_moon_moonrise_com = re.compile('<td class="pr-">(Mondaufgang:)</td>.+?<td>(.+?)</td>', re.S|re.I)
sun_moon_moonset_com = re.compile('<td class="pr-">(Monduntergang:)</td>.+?<td>(.+?)</td>', re.S|re.I)
sun_moon_zodiacsigns_com = re.compile('<td class="pr-">(Tierkreiszeichen:)</td.+?td>(.+?)</td>', re.S|re.I)

findinter_com = re.compile(r'-?\d+\.?\d*', re.S|re.I)
li_com = re.compile('<.*?>')
remove_html_com = re.compile('&.*?;')

aktuelleswetterin_com = re.compile('class="rtw_cnt.+?rtw_temp.+?</div>.+?</div>.+?</div>', re.S|re.I)
aktuelleswettername_com = re.compile(r'<h2 class=".+?">(.+?)</h2>', re.S|re.I)
aktuelleswettertemp_com = re.compile(r'<div class=".+?rtw_temp">(.+?)</div>', re.S|re.I)
aktuelleswettertext_com = re.compile(r'<span class=".+?rtw_weather_txt.+?">(.+?)</span>', re.S|re.I)

data_rtw_com = re.compile(r'<div data-rtw="(.+?)"', re.S|re.I)
data_rtw_comtest = re.compile(r'.+({&quot;date.+?)]}"', re.S|re.I)
data_rtwname_com = re.compile(r'<div class="info-location">.+?<h2 class=".+?">(.+?)</h2>', re.S|re.I)
sub_from_com = re.compile('&quot;')
fingerprint_com = re.compile(r'fingerprint&quot;:null', re.S|re.I)
data_wetternotification_com = re.compile(r'data-WetterNotification.+?data-last-update="(.+?)".+?data-poll-interval="(.+?)"', re.S|re.I)
sun_hours_com = re.compile(r'<p class="mb-">.+?<span class="text--gray">(.+?)</span>', re.S|re.I)

def parse_aktuell_icon_update(masresult, parseweathercheck = False):
	print '[wettercom.py] parse_aktuell_icon_update', parseweathercheck
	if parseweathercheck:
		if weathercheck['iconupdate'] and pathExists(weathercheck['iconupdate'][1]):
			weathercheck['list'][checklist['wettericon']] = Load_My_Pixmap(weathercheck['iconupdate'][1])
			weatherchecksetlist(weathercheck['list'])
			#for x in weathercheck['changed']:
			#	x()
		weathercheck['iconupdate'] = []
	else:
		if _masterdict['iconupdate'] and pathExists(_masterdict['iconupdate'][1]):
			_masterdict['aktuelllist'][checklist['wettericon']] = Load_My_Pixmap(_masterdict['iconupdate'][1])
			if WetterComMain.CHANGED_AKTUEL:
				WetterComMain.CHANGED_AKTUEL()
			#for x in _masterdict['changedaktuel']:
			#	x()
		_masterdict['iconupdate'] = []
		
def parse_aktuell(masresult, parseweathercheck = False):

	tmplist = checklistval[:]
	
	data_wetternotification_val = data_wetternotification_com.search(masresult)
	if data_wetternotification_val:
		dtmp = datetime.fromtimestamp(int(data_wetternotification_val.group(1))).strftime("%d.%m.%Y %H:%M:%S")
		tmplist[checklist['updatetime']] = '{}'.format(dtmp[11:16])
		#tmplist[checklist['updatetimelong']] = '{}'.format(dtmp)
		"""if parseweathercheck:
			#weathercheck['intervalorg'] = int(data_wetternotification_val.group(2))
			if weathercheck['loopingcall'] and weathercheck['interval'] in (3602, 3622):
				dt1 = datetime.fromtimestamp(int(nowtime()))
				hour = dt1.hour
				if weathercheck['interval'] == 3602:
					minute = 05
				else:
					minute = 22
				if dt1.minute >= minute:
					hour += 1
				sec = timedelta(hours=hour, minutes=minute).total_seconds() - timedelta(hours=dt1.hour, minutes=dt1.minute).total_seconds()
				if sec and weathercheck['loopingcall'].interval != sec:
					print weathercheck['loopingcall'].interval, sec
					weathercheck['loopingcall'].interval = sec
					#weathercheck['loopingcall'].starttime = weathercheck['loopingcall'].clock.seconds()
					weathercheck['loopingcall'].reset()"""
				
	dataname = data_rtwname_com.search(masresult)
	if dataname:
		tmplist[checklist['stationname']] = dataname.group(1)
	
	swg_row_wrapper = master3_com.search(masresult)
	if swg_row_wrapper:
		swg_col_text_val = swg_col_text_com.search(swg_row_wrapper.group())
		if swg_col_text_val: 
			tmplist[checklist['wettertext']] = swg_col_text_val.group(1).strip()
		wettericon_val = wettericon_com.search(swg_row_wrapper.group())
		iconval = 'd_default.svg'
		#print wettericon_val.group(1)
		if wettericon_val and wettericon_val.group(1).endswith('svg'):
			iconval = wettericon_val.group(1)
		icon = '{0}icons/{1}'.format(plugindir, iconval) 
		#print icon
		if pathExists(icon):
			tmplist[checklist['wettericon']] = Load_My_Pixmap(icon)
		else:
			if parseweathercheck:
				weathercheck['iconupdate'] = [WEATHER_ICON_URL.format(iconval), icon]
			else:
				_masterdict['iconupdate'] = [WEATHER_ICON_URL.format(iconval), icon]
		
		tempmax_val = tempmax_com.search(swg_row_wrapper.group())
		if tempmax_val:
			tmplist[checklist['temperature']] = tempmax_val.group(1)
	
		raintext_val = raintext_com.search(swg_row_wrapper.group())
		if raintext_val:
			tmplist[checklist['raintext']] = raintext_val.group(1).replace('&#8239;',' ').strip()
		rainamount_val = rainamount_com.search(swg_row_wrapper.group())
		if rainamount_val:
			tmplist[checklist['rainamounttext']] = rainamount_val.group(1).replace('&lt;','<').replace('&gt;','>').replace('&#8239;',' ').strip()
		winddirection_val = winddirection_com.search(swg_row_wrapper.group())
		if winddirection_val:
			tmplist[checklist['winddirectiontext']] = winddirection_val.group(1).replace('&nbsp;','').strip()
			tmplist[checklist['winddirectionicon']] = Load_My_Pixmap('{0}icons/ic_modern_weather_wind_{1}.png'.format(plugindir, tmplist[checklist['winddirectiontext']].lower()))
	elif not swg_row_wrapper and not parseweathercheck:		
		aktuellres = aktuelleswetterin_com.search(masresult)
		if aktuellres:
			#tmp = aktuelleswettername_com.search(aktuellres.group())
			#if tmp:
			#	tmplist[checklist['stationname']] = tmp.group(1)
			iconurl = wettericonurl_com.search(aktuellres.group())
			if iconurl:
				iconid = wettericonsvg_com.search(iconurl.group())
				if iconid:
					icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
					#print '#'*30, iconurl.group(1).strip()
					if pathExists(icon):
						tmplist[checklist['wettericon']] = Load_My_Pixmap(icon)
					else:
						_masterdict['iconupdate'] = [iconurl.group(1).strip(), icon]
	
			tmp = aktuelleswettertemp_com.search(aktuellres.group())
			if tmp:
				tmplist[checklist['temperature']] = tmp.group(1).strip()
			tmp = aktuelleswettertext_com.search(aktuellres.group())
			if tmp:
				tmplist[checklist['wettertext']] = tmp.group(1).strip()
				
	
	#_masterdict['aktuelllist'] = tmplist[:]
	#print _masterdict['aktuelllist']
	#if WetterComMain.CHANGED_AKTUEL:
	#	WetterComMain.CHANGED_AKTUEL()
	"""return True
	
	dataresult = data_rtw_com.search(masresult)
	if dataresult:# and not fingerprint_com.search(dataresult.group()):
		'''dataval = sub_from_com.sub('"', dataresult.group(1))
	
		data = json.loads(dataval)
		datalen = len(data['items'])
		dataval = data['items'][datalen-1]
		print dataval['date']
		print dataval['weather']['icon'], dataval['weather']['shortText']
		print dataval['temperature']['avg'], dataval['temperature']['unit']'''
		
		dataname = data_rtwname_com.search(masresult)
		if dataname:
			tmplist[checklist['stationname']] = dataname.group(1)
		
		
		datares = data_rtw_comtest.search(dataresult.group())
		if datares:
			datares2 = sub_from_com.sub('"', datares.group(1))
			dataval = json.loads(datares2)
			iconval = 'd_default.svg'
			if dataval['weather']['icon'] and dataval['weather']['icon'].endswith('svg'):
				iconval = dataval['weather']['icon']
			icon = '{0}icons/{1}'.format(plugindir, iconval) 
			#print '#'*30, icon
			#if icon.endswith('svg'):
			if pathExists(icon):
				tmplist[checklist['wettericon']] = Load_My_Pixmap(icon)
			else:
				if parseweathercheck:
					weathercheck['iconupdate'] = [WEATHER_ICON_URL.format(iconval), icon]
				else:
					_masterdict['iconupdate'] = [WEATHER_ICON_URL.format(iconval), icon]
		
		tmplist[checklist['wettertext']] = '{}'.format(dataval['weather']['shortText'])
		tmplist[checklist['updatetime']] = '{}'.format(dataval['date'][11:16])
		
		new_date_com = re.compile(r'<div class="\[ mb \]".*?, (.*?) .*?</div>', re.S)
		dateresult = new_date_com.findall(masresult)
		if dateresult:
			tmplist[checklist['updatetime']] = '{}'.format(dateresult[0])
		
		tmplist[checklist['temperature']] = '{0}{1}'.format(dataval['temperature']['avg'], dataval['temperature']['unit'])
	else:
		aktuellres = aktuelleswetterin_com.search(masresult)
		if aktuellres:
			tmp = aktuelleswettername_com.search(aktuellres.group())
			if tmp:
				tmplist[checklist['stationname']] = tmp.group(1)
			iconurl = wettericonurl_com.search(aktuellres.group())
			if iconurl:
				iconid = wettericonsvg_com.search(iconurl.group())
				if iconid:
					icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
					#print '#'*30, iconurl.group(1).strip()
					if pathExists(icon):
						tmplist[checklist['wettericon']] = Load_My_Pixmap(icon)
					else:
						if parseweathercheck:
							weathercheck['iconupdate'] = [iconurl.group(1).strip(), icon]
						else:
							_masterdict['iconupdate'] = [iconurl.group(1).strip(), icon]
	
			tmp = aktuelleswettertemp_com.search(aktuellres.group())
			if tmp:
				tmplist[checklist['temperature']] = tmp.group(1).strip()
			tmp = aktuelleswettertext_com.search(aktuellres.group())
			if tmp:
				tmplist[checklist['wettertext']] = tmp.group(1).strip()
			tmplist[checklist['updatetime']] = strftime("%H:%M", localtime(int(nowtime())))"""
	
	tmplist[checklist['lastcheck']] = strftime("%d.%m.%Y %H:%M:%S", localtime(int(nowtime())))
	
	if parseweathercheck:
		print '[wettercom.py] aktuell weathercheck'
		weathercheck['list'] = tmplist[:]
		weathercheck['list'][checklist['namelong']] = weathercheck['station'][0]
		
		#for x in weathercheck['changed']:
		#	x()
		weatherchecksetlist(weathercheck['list'])
		if weathercheck['iconupdate']:
			_downloads.settokens(1)
			_downloads.run(MydownloadPage, url=weathercheck['iconupdate'][0], file=weathercheck['iconupdate'][1], headers=_headers_svg).addCallback(parse_aktuell_icon_update, parseweathercheck).addErrback(http_failed, title='Wetter.com weathercheck iconupdate')
	else:
		print '[wettercom.py] aktuell main'
		#titledescription = titledescription_com.search(masresult)
		#if titledescription:
		#	tmplist[checklist['title']] = titledescription.group(1)
		_masterdict['aktuelllist'] = tmplist[:]
		if WetterComMain.CHANGED_AKTUEL:
			WetterComMain.CHANGED_AKTUEL()
		#for x in _masterdict['changedaktuel']:
		#	x()
		#if weathercheck['loopingcall'] and weathercheck['loopingcall'].running:
		#	weathercheck['list'] = tmplist[:]
		#	if weathercheck['stopstandby']:
		#		weatherchecksetlist(weathercheck['list'])
		if _masterdict['iconupdate']:
			_downloads.settokens(1)
			_downloads.run(MydownloadPage, url=_masterdict['iconupdate'][0], file=_masterdict['iconupdate'][1], headers=_headers_svg).addCallback(parse_aktuell_icon_update, parseweathercheck).addErrback(http_failed, title='Wetter.com aktuelllist iconupdate')
	return True
		
		
def clear_space(value):
	return li_com.sub(' ', value).replace('  ','').replace('\n','').strip()

def clear_html(value, valueto=' '):
	return remove_html_com.sub(valueto, value).strip()
	
def windchill(temp, wind):
	WCI = (13.12 + 0.6215 * temp) -  (11.37 * pow(wind, 0.16)) + (0.3965 * temp * pow(wind, 0.16))
	return '{0}'.format(int(round(WCI)))


def parse_main(result):

	#load_furtherdetails(result)
	if not _masterdict['furtherdetails']:
		MyCallLater(0.1, load_furtherdetails, result)
	master = master2_com.search(result)
	if master:
		def doCallLater():
			if _masterdict['aktuelllist'] and not _masterdict['aktuelllist'][checklist['stationname']]:
				parse_aktuell(result)
			sun_moon_parse(sun_moon_master_com.findall(master.group()))
		from twisted.internet import reactor
		reactor.callLater(0.0, doCallLater)
		#MyCallLater(0.0, doCallLater)
		
		master_val = master2_val_com.findall(master.group())
		mytime = int(nowtime())
		dateadd = strftime("%y", localtime(mytime))
		mindex = listmainindex
		for index in range(len(master_val)):
			tmplist = listmainval[:]
			tmp = date_com.search(master_val[index])
			if tmp:
				dateval = tmp.group(1).strip().capitalize()
				if '.' in dateval:
					dateval += dateadd
				else:
					dateval = strftime("%a %d.%m.%y", localtime(mytime))
					mytime += 86400
				tmplist[mindex['date']] = dateval
			tmp = data_grid_child_com.search(master_val[index])
			if tmp:
				tmplist[mindex['dayposition']] = tmp.group(1)
			tmp = swg_col_text_com.search(master_val[index])
			if tmp:
				tmplist[mindex['wettertext']] = clear_space(tmp.group(1))
			tmp = wettericonurl_com.search(master_val[index])
			if tmp:
				iconid = wettericonsvg_com.search(tmp.group())
				if iconid:
					icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
					if pathExists(icon):
						tmplist[mindex['wettericon']] = Load_My_Pixmap(icon)
					else:
						if iconid.group(1) not in _masterdict['wettericon']:
							_masterdict['wettericon'][iconid.group(1)] = []
						_masterdict['wettericon'][iconid.group(1)].append([tmp.group(1),icon, index])
			tmp = tempmax_com.search(master_val[index])
			if tmp:
				tmplist[mindex['tempmax']] = tmp.group(1).strip()
			tmp = tempmin2_com.search(master_val[index])
			if tmp:
				tmplist[mindex['tempmin']] = tmp.group(1).replace('&thinsp;',' ').strip()
			tmp = raintext_com.search(master_val[index])
			if tmp:
				tmplist[mindex['raintext']] = tmp.group(1).replace('&#8239;',' ').strip()
				tmplist[mindex['rainicon']] = Load_My_Pixmap('{0}icons/ic_modern_precipitation_risk_s.png'.format(plugindir))
			tmp = rainamount_com.search(master_val[index])
			if tmp:
				tmplist[mindex['rainamounttext']] = tmp.group(1).replace('&lt;','<').replace('&gt;','>').replace('&#8239;',' ').strip()
				tmplist[mindex['rainamounticon']] = Load_My_Pixmap('{0}icons/ic_modern_weather_no_rain.png'.format(plugindir))
			tmp = windspeed_com.search(master_val[index])
			if tmp:
				tmplist[mindex['windspeed']] = clear_space(tmp.group(1)).replace('&#8239;',' ')
			tmp = tempfelt_com.search(master_val[index])
			if tmp:
				#print tmp.group(1)
				tmplist[mindex['tempfelt']] = '{0} {1}'.format(tmp.group(1), tmp.group(2).replace('&thinsp;',' ').strip())
			tmp = winddirection_com.search(master_val[index])
			if tmp:
				tmplist[mindex['winddirectiontext']] = tmp.group(1).replace('&nbsp;','').strip()
				tmplist[mindex['winddirectionicon']] = Load_My_Pixmap('{0}icons/ic_modern_weather_wind_{1}.png'.format(plugindir, tmplist[mindex['winddirectiontext']].lower()))
		
			_masterdict['mlist'].append(tmplist)
		return titledescription_com.search(result)
	else:
		return parse_oly_day(result)
		
def sun_moon_parse(sun_moon_list):
	
	mytime = int(nowtime())
	sindex = listsunmoonindex
	for index in range(len(sun_moon_list)):
		tmplist = listsunmoonval[:]
		tmplist[sindex['date']] = strftime("%a %d.%m.%y", localtime(mytime))
		mytime += 86400
		tmp = sun_moon_sunrise_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['sunrisetitle']] = tmp.group(1)
			tmplist[sindex['sunrisevalue']] = tmp.group(2).strip()
			tmplist[sindex['sunriseicon']] = Load_My_Pixmap('{0}icons/ic_classic_weather_sunrise.png'.format(plugindir))
		tmp = sun_moon_sunset_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['sunsettitle']] = tmp.group(1)
			tmplist[sindex['sunsetvalue']] = tmp.group(2).strip()
			tmplist[sindex['sunseticon']] = Load_My_Pixmap('{0}icons/ic_classic_weather_sunset.png'.format(plugindir))
		tmp = sun_moon_sunshine_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['sunshinetitle']] = tmp.group(1)
			tmplist[sindex['sunshinevalue']] = tmp.group(2)#.strip()
			#tmplist[sindex['sunshineicon']] = Load_My_Pixmap('{0}icons/ic_classic_sun.png'.format(plugindir))
		tmp = sun_moon_moonicon_com.search(sun_moon_list[index])
		if tmp:
			if tmp.group(1) in _moondict:
				tmplist[sindex['moonicon']] = Load_My_Pixmap('{0}icons/{1}.png'.format(plugindir,_moondict[tmp.group(1)]))
				#print tmplist[sindex['moonicon']]
			tmplist[sindex['moontitle']] = tmp.group(2)
		tmp = sun_moon_moontext_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['moontext']] = tmp.group(1)
		tmp = sun_moon_moonrise_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['moonrisetitle']] = tmp.group(1)
			tmplist[sindex['moonrisevalue']] = tmp.group(2)
			tmplist[sindex['moonriseicon']] = Load_My_Pixmap('{0}icons/ic_modern_moonrise.png'.format(plugindir))
		tmp = sun_moon_moonset_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['moonsettitle']] = tmp.group(1)
			tmplist[sindex['moonsetvalue']] = tmp.group(2)
			tmplist[sindex['moonseticon']] = Load_My_Pixmap('{0}icons/ic_modern_moonset.png'.format(plugindir))
		tmp = sun_moon_zodiacsigns_com.search(sun_moon_list[index])
		if tmp:
			tmplist[sindex['zodiacsignstitle']] = tmp.group(1)
			tmplist[sindex['zodiacsignsvalue']] = tmp.group(2)
		tmplist[sindex['sunshineicon']] = Load_My_Pixmap('{0}icons/ic_classic_sun.png'.format(plugindir))
		
		#print tmplist
		_masterdict['sunmoon'].append(tmplist)
	if WetterComMain.CHANGED_TITLELIST:
		WetterComMain.CHANGED_TITLELIST()
		#for x in _masterdict['changedlist']:
		#	x()
	#print _masterdict['sunmoon'][0]
	
def parse_oly_day(result):

	master = master_com.search(result)
	master_val = master_val_com.findall(master.group())
	
	def doCallLater():
		if _masterdict['aktuelllist'] and not _masterdict['aktuelllist'][checklist['stationname']]:
			parse_aktuell(result)
		sun_moon_parse([sun_moon_master_com.search(result).group()])
		#sun_hours_val = sun_hours_com.search(result)
		#if sun_hours_val and _masterdict['sunmoon']:
		#	_masterdict['sunmoon'][0][listsunmoonindex['sunshinetitle']] = sun_hours_val.group(1).strip()
	from twisted.internet import reactor
	reactor.callLater(0.0, doCallLater)
	#MyCallLater(0.0, doCallLater)
	
	mindex = listmainindex
	for index in range(len(master_val)):
		tmplist = listmainval[:]
		#tmplist[mindex['date']] = strftime("%a %d.%m.%y", localtime(_masterdict['mytime']))
		tmp = data_num_com.search(master_val[index])
		if tmp:
			tmplist[mindex['dayposition']] =  tmp.group(1).strip()
		tmp = swg_col_period_com.search(master_val[index])
		if tmp:
			tmplist[mindex['daytime']] =  tmp.group(1).strip()
			if _masterdict['mytime']:
				if index == 0:
					tmplist[mindex['date']] = strftime("%a %d.%m.%y", localtime(_masterdict['mytime']))
				elif tmplist[mindex['daytime']].startswith('00'):
					_masterdict['mytime'] += 86400
					tmplist[mindex['date']] = strftime("%a %d.%m.%y", localtime(_masterdict['mytime']))
		tmp = swg_col_text_com.search(master_val[index])
		if tmp:
			tmplist[mindex['wettertext']] = clear_space(tmp.group(1))
		tmp = wettericonurl_com.search(master_val[index])
		if tmp:
			iconid = wettericonsvg_com.search(tmp.group())
			if iconid:
				icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
				if pathExists(icon):
					tmplist[mindex['wettericon']] = Load_My_Pixmap(icon)
				else:
					if iconid.group(1) not in _masterdict['wettericon']:
						_masterdict['wettericon'][iconid.group(1)] = []
					_masterdict['wettericon'][iconid.group(1)].append([tmp.group(1),icon, index])	
		tmp = tempmax_com.search(master_val[index])
		if tmp:
			tmplist[mindex['tempmax']] = tmp.group(1).strip()
		tmp = raintext_com.search(master_val[index])
		if tmp:
			tmplist[mindex['raintext']] = tmp.group(1).replace('&#8239;',' ').strip()
			tmplist[mindex['rainicon']] = Load_My_Pixmap('{0}icons/ic_modern_precipitation_risk_s.png'.format(plugindir))	
		tmp = rainamount_com.search(master_val[index])
		if tmp:
			tmplist[mindex['rainamounttext']] = tmp.group(1).replace('&lt;','<').replace('&gt;','>').replace('&#8239;',' ').strip()
			tmplist[mindex['rainamounticon']] = Load_My_Pixmap('{0}icons/ic_modern_weather_no_rain.png'.format(plugindir))
		tmp = windspeed_com.search(master_val[index])
		if tmp:
			tmplist[mindex['windspeed']] = clear_space(tmp.group(1)).replace('&#8239;',' ')
			if tmplist[mindex['windspeed']] and tmplist[mindex['tempmax']]:
				temp = findinter_com.search(tmplist[mindex['tempmax']])
				wind = findinter_com.search(tmplist[mindex['windspeed']])
				if temp and wind:
					if temp.group().isdigit() and wind.group().isdigit():
						tmplist[mindex['tempfelt']] = '{0} {1}°'.format(_('feeling'), windchill(int(temp.group()), int(wind.group())))
		tmp = winddirection_com.search(master_val[index])
		if tmp:
			tmplist[mindex['winddirectiontext']] = tmp.group(1).replace('&nbsp;','').strip()
			tmplist[mindex['winddirectionicon']] = Load_My_Pixmap('{0}icons/ic_modern_weather_wind_{1}.png'.format(plugindir, tmplist[mindex['winddirectiontext']].lower()))
			
		_masterdict['mlist'].append(tmplist)
	return titledescription_com.search(result)

def loopweathercheck(ltime=0.0):
	#print weathercheck['loopingcall'].running, weathercheck['loopingcall'].interval
	if weathercheck['loopingcall'] and weathercheck['interval'] in (3602, 3622):
		dt1 = datetime.fromtimestamp(int(nowtime()))
		hour = dt1.hour
		if weathercheck['interval'] == 3602:
			minute = 02
		else:
			minute = 22
		if dt1.minute >= minute:
			hour += 1
		sec = timedelta(hours=hour, minutes=minute).total_seconds() - timedelta(hours=dt1.hour, minutes=dt1.minute).total_seconds()
		if sec and weathercheck['loopingcall'].interval != sec:
			print 'loopingcall update', weathercheck['loopingcall'].interval, sec
			weathercheck['loopingcall'].interval = sec
			weathercheck['loopingcall'].reset()
	
	print '[wettercom.py] loopweathercheck'
	_downloads.settokens(1)
	_downloads.rundeferLater(ltime, MygetPage, url=WEATHER_TODAY_URL.format(weathercheck['station'][1]), headers=headers_gzip).addCallback(parse_aktuell, True).addErrback(http_failed, title='Wetter.com loopweathercheck')
	
	
furtherdetails_com = re.compile(r'id="furtherDetails" data-module=.+?<div class="layout__item">', re.S|re.I)
furtherdetails_h2h3_com = re.compile(r'<h2>(.+?)</h2>.+?<h3>(.+?)</h3>(.+?)<[hr|p>]', re.S|re.I)
furtherdetails_detail_list_com = re.compile(r'data-label=.+?</div>.+?</a>', re.S|re.I)
#furtherdetails_wig_label_com = re.compile(r'<div class="wig-label">(.+?)</div>', re.S|re.I)
furtherdetails_detailwetter_com = re.compile(r'data-label="Detailwetter_(.+?)"', re.S|re.I)
furtherdetails_href_com = re.compile(r'href="(.+?)"', re.S|re.I)
furtherdetails_wig_temperature_com = re.compile(r'<span class="gamma">(.+?)</span>(.+?)<span class="">(.+?)</span>', re.S|re.I)
furtherdetails_title_com = re.compile(r'title="(.+?)"', re.S|re.I)


sub_br_com = re.compile('<br.+?/>')

furtherindex = {}
furtherindex['stationname'] = 0
furtherindex['temperature'] = 1
furtherindex['wettertext'] = 2
furtherindex['wettericon'] = 3
furtherindex['stationurl'] = 4
furtherindex['stationid'] = 5
furtherindex['dummy'] = 6
furtherindex['listend'] = 7

furtherval = ['']*furtherindex['listend']
furtherval[furtherindex['wettericon']] = None

def load_furtherdetails(result):
	master = furtherdetails_com.search(result)
	if master:
		#parse_furtherdetails(master)
		WetterComMain.INFOICON.boolean = True
		_masterdict['furtherdetails'] = master
	else:
		WetterComMain.INFOICON.boolean = False
		
def parse_furtherdetails(master):
	#_masterdict['furtherdetails']['list'] = furtherval[:]#{'list':[],'details':''}
	#master = furtherdetails_com.search(result)
	titlelist = ['','','']
	resultlist = []
	if master:
		#print master.group()
		tmp = furtherdetails_h2h3_com.search(master.group())
		if tmp:
			#print tmp.groups()#.strip()
			titlelist[0] = tmp.group(1).strip()
			titlelist[1] = tmp.group(2).strip()
			titlelist[2] = tmp.group(3).replace('<br /> ','\n').replace('<br />','\n').strip()#sub_br_com.sub('\n',tmp.group(3)).strip()
		
		#print titlelist
		#return
		furtherdetails_detail_val = furtherdetails_detail_list_com.findall(master.group())
		#print furtherdetails_detail_val[0]
		for index in range(len(furtherdetails_detail_val)):
			tmplist = furtherval[:]
			tmp = furtherdetails_detailwetter_com.search(furtherdetails_detail_val[index])
			if tmp:
				#print tmp.group(1).strip()
				tmplist[furtherindex['stationname']] = tmp.group(1).strip()
				
			tmp = furtherdetails_href_com.search(furtherdetails_detail_val[index])
			if tmp:
				#print tmp.group(1).strip()
				tmplist[furtherindex['stationurl']] = tmp.group(1).strip()
				tmplist[furtherindex['stationid']] = tmplist[furtherindex['stationurl']][tmplist[furtherindex['stationurl']].rfind('/')+1:-5]
			
			iconurl = wettericonurl_com.search(furtherdetails_detail_val[index])
			if iconurl:
				#print iconurl.group(1).strip()
				iconid = wettericonsvg_com.search(iconurl.group())
				if iconid:
					icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
					if pathExists(icon):
						tmplist[furtherindex['wettericon']] = Load_My_Pixmap(icon)
						#print iconid.group(1)
					else:
						tmplist[furtherindex['wettericon']] = Load_My_Pixmap('d_default.svg')
			tmp = furtherdetails_wig_temperature_com.search(furtherdetails_detail_val[index])
			if tmp:
				tmplist[furtherindex['temperature']] = ''.join(tmp.groups())
			
			tmp = furtherdetails_title_com.search(furtherdetails_detail_val[index])
			if tmp:
				tmplist[furtherindex['wettertext']] = tmp.group(1)
			#print tmplist
			resultlist.append(tmplist)
			#return
	return titlelist, resultlist
			
def parse_check_day(masresult):
	
	weathercheck['list'] = listmainval[:]
	#print weathercheck['list']
	master = master3_com.search(masresult)
	mindex = listmainindex
	#print master.group()
	tmp = data_num_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['dayposition']] = tmp.group(1).strip()
	tmp = swg_col_period_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['daytime']] =  tmp.group(1).strip()
		weathercheck['list'][mindex['date']] = strftime("%a %d.%m.%y", localtime(int(nowtime())))
	tmp = swg_col_text_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['wettertext']] = clear_space(tmp.group(1))
	tmp = wettericonurl_com.search(master.group())
	if tmp:
		iconid = wettericonsvg_com.search(tmp.group())
		if iconid:
			icon = '{0}icons/{1}'.format(plugindir, iconid.group(1))
			if pathExists(icon):
				weathercheck['list'][mindex['wettericon']] = Load_My_Pixmap(icon)
	tmp = tempmax_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['tempmax']] = tmp.group(1).strip()
	tmp = raintext_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['raintext']] = tmp.group(1).replace('&#8239;',' ').strip()
	tmp = rainamount_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['rainamounttext']] = tmp.group(1).replace('&lt;','<').replace('&gt;','>').replace('&#8239;',' ').strip()	
	tmp = windspeed_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['windspeed']] = clear_space(tmp.group(1)).replace('&#8239;',' ')
		if weathercheck['list'][mindex['windspeed']] and weathercheck['list'][mindex['tempmax']]:
			temp = findinter_com.search(weathercheck['list'][mindex['tempmax']])
			wind = findinter_com.search(weathercheck['list'][mindex['windspeed']])
			if temp and wind:
				if temp.group().isdigit() and wind.group().isdigit():
					weathercheck['list'][mindex['tempfelt']] = '{0} {1}°'.format(_('feeling'), windchill(int(temp.group()), int(wind.group())))	
	tmp = winddirection_com.search(master.group())
	if tmp:
		weathercheck['list'][mindex['winddirectiontext']] = tmp.group(1).replace('&nbsp;','').strip()
	
	for x in weathercheck['changed']:
		x()
	return True
	
def weatherchecksetlist(list):
	from API import session as mysession
	if mysession and mysession.screen.has_key("WetterCom"):
		print '[wettercom.py] weatherchecksetlist'
		mysession.screen["WetterCom"].current = list

def parse_json(masresult):
	data = json.loads(masresult)
	
	result = []
	for dataval in data["suggest"]['location'][0]["options"]:
		result.append([dataval['_source']['name'].encode('utf-8'), dataval['_source']['slug'], dataval['_source']['originId']])
	return result
	
def read_weather_stations():
	if pathExists(WEATHER_STATIONS):
		with open(WEATHER_STATIONS) as data_file:
			data = json.load(data_file, encoding='utf-8')
			for name, url, id in data:
				_masterdict['stations'].append([name.encode('utf-8'), url.encode('utf-8'), id.encode('utf-8')])
	else:
		_masterdict['stations'].append(DEFAULTSTATIONS)
		
def write_weather_stations():			
	with open(WEATHER_STATIONS, 'w') as fp:
		json.dump(_masterdict['stations'], fp, encoding='utf-8', indent=2, sort_keys=True)
		
def write_weather_config():
	tmp = {}
	#tmp['stations_name'] = _masterdict['stations_name']
	#tmp['stations_id'] = _masterdict['stations_id']
	
	tmp['station'] = _masterdict['station']
	tmp['startkey'] = _masterdict['startkey']
	with open(WEATHER_CONFIG, 'w') as fp:
		json.dump(tmp, fp, encoding='utf-8', indent=2, sort_keys=True)
		
def read_weather_config():
	if pathExists(WEATHER_CONFIG):
		with open(WEATHER_CONFIG) as data_file:
			data = json.load(data_file, encoding='utf-8')
			#_masterdict['stations_name'] = data.get('stations_name', DEFAULTSTATIONS_NAME)
			#_masterdict['stations_id'] = data.get('stations_id', DEFAULTSTATIONS_URL)
			tmp = data.get('station', DEFAULTSTATIONS)
			_masterdict['station'] = [tmp[0].encode('utf-8'), tmp[1].encode('utf-8'), tmp[2].encode('utf-8')]
			_masterdict['startkey'] = data.get('startkey', 'today')
			
			
def read_weather_check_config():
	if pathExists(WEATHER_CHECK_CONFIG):
		with open(WEATHER_CHECK_CONFIG) as data_file:
			data = json.load(data_file, encoding='utf-8')
			weathercheck['interval'] = data.get('interval', 0)
			weathercheck['infobarscreen'] = data.get('infobarscreen', False)
			weathercheck['stopstandby'] = data.get('stopstandby', True)
			tmp = data.get('station', DEFAULTSTATIONS)
			weathercheck['station'] = [tmp[0].encode('utf-8'), tmp[1].encode('utf-8'), tmp[2].encode('utf-8')]
				
			
def write_weather_check_config():
	#if weathercheck['interval'] > 100:
	tmp = {}
	tmp['interval'] = weathercheck['interval']
	tmp['infobarscreen'] = weathercheck['infobarscreen']
	tmp['stopstandby'] = weathercheck['stopstandby']
	tmp['station'] = weathercheck['station']
	with open(WEATHER_CHECK_CONFIG, 'w') as fp:
		json.dump(tmp, fp, encoding='utf-8', indent=2, sort_keys=True)
	#elif pathExists(WEATHER_CHECK_CONFIG):
	#	os_remove(WEATHER_CHECK_CONFIG)
		
			